@@ -22,10 +22,11 @@ solver="""if not terminating:
     solver_construction += '\\n'
     solver_construction += 'Resistance Values:'
     faces = mesher.get_model_face_ids()
+    outlet_res_total = {}
     for j in range(2,len(mesher.get_model_face_ids())+1):
         if j == skip:
             continue
-        solver_construction += ' {{}}'.format(round(1/resistance[faces[j-1]],2))
+        solver_construction += ' {{}}'.format(round(((1/resistance[faces[j-1]])/total_res)*outlet_res_total,2))
     solver_construction += '\\n\\n'
     solver_construction += 'Pressure Coupling: {}\\n'
     solver_construction += 'Number of Coupled Surfaces: {{}}\\n\\n'.format(num_res)
@@ -52,7 +53,5 @@ solver="""if not terminating:
     numstart = open('{}'+'/numstart.dat','w+')
     numstart.writelines(['0'])
     numstart.close()
-    flow_file = open('{}'+'/{}','w+')
-    flow_file.writelines(['0 -{}\\n','1 -{}'])
-    flow_file.close()
+
 """
